@@ -107,7 +107,7 @@ func TestMakeRequest(t *testing.T) {
 	fxt, err := NewFixtureFromFile(fs, apiKey, "", ts.URL, file, []string{}, []string{}, []string{}, []string{})
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 
 	require.NotNil(t, fxt.responses["cust_bender"])
@@ -139,7 +139,7 @@ func TestMakeRequestWithStringFixture(t *testing.T) {
 	fxt, err := NewFixtureFromRawString(fs, apiKey, "", ts.URL, testFixture)
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 
 	require.NotNil(t, fxt.responses["cust_bender"])
@@ -169,7 +169,7 @@ func TestWithSkipMakeRequest(t *testing.T) {
 	fxt, err := NewFixtureFromFile(fs, apiKey, "", ts.URL, file, []string{"char_bender", "capt_bender"}, []string{}, []string{}, []string{})
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 
 	require.True(t, fxt.responses["cust_bender"].Exists())
@@ -210,7 +210,7 @@ func TestMakeRequestWithOverride(t *testing.T) {
 	fxt, err := NewFixtureFromFile(fs, apiKey, "", ts.URL, file, []string{}, []string{"cust_bender:name=Fry", "char_bender:amount=3000"}, []string{}, []string{})
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 }
 
@@ -255,7 +255,7 @@ func TestMakeRequestWithAdd(t *testing.T) {
 	)
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 }
 
@@ -293,7 +293,7 @@ func TestMakeRequestWithRemove(t *testing.T) {
 	)
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 }
 
@@ -309,7 +309,7 @@ func TestMakeRequestExpectedFailure(t *testing.T) {
 	fxt, err := NewFixtureFromFile(fs, apiKey, "", ts.URL, "failured_test_fixture.json", []string{}, []string{}, []string{}, []string{})
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 	require.NotNil(t, fxt.responses["charge_expected_failure"])
 }
@@ -326,7 +326,7 @@ func TestMakeRequestUnexpectedFailure(t *testing.T) {
 	fxt, err := NewFixtureFromFile(fs, apiKey, "", ts.URL, "failured_test_fixture.json", []string{}, []string{}, []string{}, []string{})
 	require.NoError(t, err)
 
-	_, err = fxt.Execute(context.Background())
+	_, err = fxt.Execute(context.Background(), "")
 	require.NotNil(t, err)
 }
 
@@ -440,7 +440,7 @@ func TestExecuteReturnsRequestNames(t *testing.T) {
 	fxt, err := NewFixtureFromFile(fs, apiKey, "", ts.URL, file, []string{}, []string{}, []string{}, []string{})
 	require.NoError(t, err)
 
-	requestNames, err := fxt.Execute(context.Background())
+	requestNames, err := fxt.Execute(context.Background(), "")
 	require.NoError(t, err)
 
 	require.NotNil(t, fxt.responses["cust_bender"])
